/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p schedulerinterface /usr/src/ports/kf5-baloo/kf5-baloo-5.43.0-1.x86_64/build/src/dbus/org.kde.baloo.scheduler.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef SCHEDULERINTERFACE_H
#define SCHEDULERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.baloo.scheduler
 */
class OrgKdeBalooSchedulerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.baloo.scheduler"; }

public:
    OrgKdeBalooSchedulerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeBalooSchedulerInterface();

    Q_PROPERTY(int state READ state)
    inline int state() const
    { return qvariant_cast< int >(property("state")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> checkUnindexedFiles()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("checkUnindexedFiles"), argumentList);
    }

    inline QDBusPendingReply<uint> getBatchSize()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getBatchSize"), argumentList);
    }

    inline QDBusPendingReply<uint> getRemainingTime()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getRemainingTime"), argumentList);
    }

    inline QDBusPendingReply<> resume()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resume"), argumentList);
    }

    inline QDBusPendingReply<> suspend()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("suspend"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void stateChanged(int state);
};

namespace org {
  namespace kde {
    namespace baloo {
      typedef ::OrgKdeBalooSchedulerInterface scheduler;
    }
  }
}
#endif
