/****************************************************************************
** Meta object code from reading C++ file 'storagedevices.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/baloo-5.43.0/src/file/storagedevices.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagedevices.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__StorageDevices_t {
    QByteArrayData data[12];
    char stringdata0[202];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__StorageDevices_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__StorageDevices_t qt_meta_stringdata_Baloo__StorageDevices = {
    {
QT_MOC_LITERAL(0, 0, 21), // "Baloo::StorageDevices"
QT_MOC_LITERAL(1, 22, 11), // "deviceAdded"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 35), // "const Baloo::StorageDevices::..."
QT_MOC_LITERAL(4, 71, 5), // "entry"
QT_MOC_LITERAL(5, 77, 13), // "deviceRemoved"
QT_MOC_LITERAL(6, 91, 26), // "deviceAccessibilityChanged"
QT_MOC_LITERAL(7, 118, 20), // "slotSolidDeviceAdded"
QT_MOC_LITERAL(8, 139, 3), // "udi"
QT_MOC_LITERAL(9, 143, 22), // "slotSolidDeviceRemoved"
QT_MOC_LITERAL(10, 166, 24), // "slotAccessibilityChanged"
QT_MOC_LITERAL(11, 191, 10) // "accessible"

    },
    "Baloo::StorageDevices\0deviceAdded\0\0"
    "const Baloo::StorageDevices::Entry*\0"
    "entry\0deviceRemoved\0deviceAccessibilityChanged\0"
    "slotSolidDeviceAdded\0udi\0"
    "slotSolidDeviceRemoved\0slotAccessibilityChanged\0"
    "accessible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__StorageDevices[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    1,   47,    2, 0x06 /* Public */,
       6,    1,   50,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   53,    2, 0x08 /* Private */,
       9,    1,   56,    2, 0x08 /* Private */,
      10,    2,   59,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString,   11,    8,

       0        // eod
};

void Baloo::StorageDevices::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StorageDevices *_t = static_cast<StorageDevices *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->deviceAdded((*reinterpret_cast< const Baloo::StorageDevices::Entry*(*)>(_a[1]))); break;
        case 1: _t->deviceRemoved((*reinterpret_cast< const Baloo::StorageDevices::Entry*(*)>(_a[1]))); break;
        case 2: _t->deviceAccessibilityChanged((*reinterpret_cast< const Baloo::StorageDevices::Entry*(*)>(_a[1]))); break;
        case 3: _t->slotSolidDeviceAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->slotSolidDeviceRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotAccessibilityChanged((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (StorageDevices::*_t)(const Baloo::StorageDevices::Entry * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageDevices::deviceAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (StorageDevices::*_t)(const Baloo::StorageDevices::Entry * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageDevices::deviceRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (StorageDevices::*_t)(const Baloo::StorageDevices::Entry * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StorageDevices::deviceAccessibilityChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Baloo::StorageDevices::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Baloo__StorageDevices.data,
      qt_meta_data_Baloo__StorageDevices,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::StorageDevices::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::StorageDevices::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__StorageDevices.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Baloo::StorageDevices::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Baloo::StorageDevices::deviceAdded(const Baloo::StorageDevices::Entry * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Baloo::StorageDevices::deviceRemoved(const Baloo::StorageDevices::Entry * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Baloo::StorageDevices::deviceAccessibilityChanged(const Baloo::StorageDevices::Entry * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
