/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p fileindexerinterface /usr/src/ports/kf5-baloo/kf5-baloo-5.43.0-1.x86_64/build/src/dbus/org.kde.baloo.fileindexer.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "fileindexerinterface.h"

/*
 * Implementation of interface class OrgKdeBalooFileindexerInterface
 */

OrgKdeBalooFileindexerInterface::OrgKdeBalooFileindexerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeBalooFileindexerInterface::~OrgKdeBalooFileindexerInterface()
{
}


#include "fileindexerinterface.moc"
