/****************************************************************************
** Meta object code from reading C++ file 'monitor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/baloo-5.43.0/src/qml/experimental/monitor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__Monitor_t {
    QByteArrayData data[21];
    char stringdata0[282];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__Monitor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__Monitor_t qt_meta_stringdata_Baloo__Monitor = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Baloo::Monitor"
QT_MOC_LITERAL(1, 15, 14), // "newFileIndexed"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 17), // "balooStateChanged"
QT_MOC_LITERAL(4, 49, 17), // "totalFilesChanged"
QT_MOC_LITERAL(5, 67, 20), // "remainingTimeChanged"
QT_MOC_LITERAL(6, 88, 19), // "indexerStateChanged"
QT_MOC_LITERAL(7, 108, 7), // "newFile"
QT_MOC_LITERAL(8, 116, 8), // "filePath"
QT_MOC_LITERAL(9, 125, 12), // "balooStarted"
QT_MOC_LITERAL(10, 138, 7), // "service"
QT_MOC_LITERAL(11, 146, 23), // "slotIndexerStateChanged"
QT_MOC_LITERAL(12, 170, 5), // "state"
QT_MOC_LITERAL(13, 176, 18), // "toggleSuspendState"
QT_MOC_LITERAL(14, 195, 10), // "startBaloo"
QT_MOC_LITERAL(15, 206, 12), // "suspendState"
QT_MOC_LITERAL(16, 219, 12), // "balooRunning"
QT_MOC_LITERAL(17, 232, 10), // "totalFiles"
QT_MOC_LITERAL(18, 243, 12), // "filesIndexed"
QT_MOC_LITERAL(19, 256, 13), // "remainingTime"
QT_MOC_LITERAL(20, 270, 11) // "stateString"

    },
    "Baloo::Monitor\0newFileIndexed\0\0"
    "balooStateChanged\0totalFilesChanged\0"
    "remainingTimeChanged\0indexerStateChanged\0"
    "newFile\0filePath\0balooStarted\0service\0"
    "slotIndexerStateChanged\0state\0"
    "toggleSuspendState\0startBaloo\0"
    "suspendState\0balooRunning\0totalFiles\0"
    "filesIndexed\0remainingTime\0stateString"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__Monitor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       8,   80, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,
       4,    0,   66,    2, 0x06 /* Public */,
       5,    0,   67,    2, 0x06 /* Public */,
       6,    0,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   69,    2, 0x08 /* Private */,
       9,    1,   72,    2, 0x08 /* Private */,
      11,    1,   75,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      13,    0,   78,    2, 0x02 /* Public */,
      14,    0,   79,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::Int,   12,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QString, 0x00495001,
      15, QMetaType::QString, 0x00495001,
      16, QMetaType::Bool, 0x00495003,
      17, QMetaType::UInt, 0x00495003,
      18, QMetaType::UInt, 0x00495003,
      19, QMetaType::QString, 0x00495001,
      20, QMetaType::QString, 0x00495001,
      12, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       4,
       1,
       2,
       0,
       3,
       4,
       4,

       0        // eod
};

void Baloo::Monitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Monitor *_t = static_cast<Monitor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newFileIndexed(); break;
        case 1: _t->balooStateChanged(); break;
        case 2: _t->totalFilesChanged(); break;
        case 3: _t->remainingTimeChanged(); break;
        case 4: _t->indexerStateChanged(); break;
        case 5: _t->newFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->balooStarted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotIndexerStateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->toggleSuspendState(); break;
        case 9: _t->startBaloo(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Monitor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Monitor::newFileIndexed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Monitor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Monitor::balooStateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Monitor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Monitor::totalFilesChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Monitor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Monitor::remainingTimeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Monitor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Monitor::indexerStateChanged)) {
                *result = 4;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        Monitor *_t = static_cast<Monitor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->filePath(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->suspendState(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->m_balooRunning; break;
        case 3: *reinterpret_cast< uint*>(_v) = _t->m_totalFiles; break;
        case 4: *reinterpret_cast< uint*>(_v) = _t->m_filesIndexed; break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->remainingTime(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->stateString(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->state(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        Monitor *_t = static_cast<Monitor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 2:
            if (_t->m_balooRunning != *reinterpret_cast< bool*>(_v)) {
                _t->m_balooRunning = *reinterpret_cast< bool*>(_v);
                Q_EMIT _t->balooStateChanged();
            }
            break;
        case 3:
            if (_t->m_totalFiles != *reinterpret_cast< uint*>(_v)) {
                _t->m_totalFiles = *reinterpret_cast< uint*>(_v);
                Q_EMIT _t->totalFilesChanged();
            }
            break;
        case 4:
            if (_t->m_filesIndexed != *reinterpret_cast< uint*>(_v)) {
                _t->m_filesIndexed = *reinterpret_cast< uint*>(_v);
                Q_EMIT _t->newFileIndexed();
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Baloo::Monitor::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Baloo__Monitor.data,
      qt_meta_data_Baloo__Monitor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::Monitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::Monitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__Monitor.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Baloo::Monitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Baloo::Monitor::newFileIndexed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Baloo::Monitor::balooStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Baloo::Monitor::totalFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Baloo::Monitor::remainingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Baloo::Monitor::indexerStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
